@@ -71,6 +71,7 @@ factory.doc['props']['required_class'] = \
 """CSS-class to put on in case if required condition was not met.
 """
 
+# XXX: remove. Controlled by form.novalidate
 factory.defaults['html5required'] = True
 factory.doc['props']['html5required'] = \
 """Flag whether HTML5 required attribute should be rendered.
@@ -154,6 +155,7 @@ def input_generic_renderer(widget, data):
         'disabled': bool(widget.attrs.get('disabled')) and 'disabled' or None,
         'autocomplete': widget.attrs.get('autocomplete'),
     }
+    # XXX: remove. Controlled by form.novalidate
     html5required = widget.attrs['html5required']
     if html5required:
         input_attrs['required'] = \
@@ -429,6 +431,7 @@ def password_renderer(widget, data):
         'autofocus': widget.attrs.get('autofocus') and 'autofocus' or None,      
         'disabled': widget.attrs.get('disabled'),
     }
+    # XXX: remove. Controlled form.novalidate instead
     html5required = widget.attrs['html5required']
     if html5required:
         input_attrs['required'] = \
@@ -500,7 +503,7 @@ def input_checkbox_extractor(widget, data):
     raise ValueError, "Checkbox widget has invalid format '%s' set" % format
 
 
-@managedprops('format', *css_managed_props)
+@managedprops('format', 'disabled', *css_managed_props)
 def input_checkbox_renderer(widget, data):
     tag = data.tag
     value = fetch_value(widget, data)
@@ -510,7 +513,8 @@ def input_checkbox_renderer(widget, data):
         'value': value,
         'name_': widget.dottedpath,
         'id': cssid(widget, 'input'),    
-        'class_': cssclasses(widget, data),    
+        'class_': cssclasses(widget, data),
+        'disabled': bool(widget.attrs.get('disabled')) and 'disabled' or None,            
     }
     if widget.attrs['format'] == 'bool':
         input_attrs['value'] = ''
@@ -543,7 +547,7 @@ factory.register('checkbox',
 # selection
 ###############################################################################
 
-@managedprops('format', 'multivalued')
+@managedprops('format', 'multivalued', 'disabled')
 def select_extractor(widget, data):
     extracted = generic_extractor(widget, data)
     if extracted is UNSET \
@@ -552,8 +556,23 @@ def select_extractor(widget, data):
             extracted = []
         else:
             extracted = ''
+    if extracted is UNSET:
+        return extracted
     if widget.attrs['multivalued'] and isinstance(extracted, basestring):
         extracted = [extracted]
+    disabled = widget.attrs.get('disabled', False)
+    if not disabled:
+        return extracted
+    if not widget.attrs['multivalued']:
+        return data.value
+    disabled_items = disabled is True and data.value or disabled
+    if isinstance(disabled_items, basestring):
+        disabled_items = [disabled_items]
+    for item in disabled_items:
+        if item in extracted and item not in data.value:
+            extracted.remove(item)
+        elif item not in extracted and item in data.value:
+            extracted.append(item)
     return extracted
 
 
@@ -568,7 +587,7 @@ def select_exists_marker(widget, data):
     return tag('input', **attrs)
 
 
-@managedprops('format', 'vocabulary', 'multivalued', *css_managed_props)
+@managedprops('format', 'vocabulary', 'multivalued', 'disabled', *css_managed_props)
 def select_renderer(widget, data):
     tag = data.tag
     value = fetch_value(widget, data)
@@ -579,6 +598,7 @@ def select_renderer(widget, data):
         value = [value]
     if not widget.attrs['multivalued'] and len(value) > 1:
         raise ValueError(u"Multiple values for single selection.")
+    disabled = widget.attrs.get('disabled', False)
     if widget.attrs['format'] == 'block':
         optiontags = []
         for key, term in vocabulary(widget.attrs.get('vocabulary', [])):
@@ -587,7 +607,9 @@ def select_renderer(widget, data):
                 'value': key,
                 'id': cssid(widget, 'input', key),
             }
-            optiontags.append(tag('option', term, **attrs))
+            if disabled and disabled is not True and key in disabled:
+                attrs['disabled'] = 'disabled'                 
+            optiontags.append(tag('option', term, **attrs))            
         select_attrs = {
             'name_': widget.dottedpath,
             'id': cssid(widget, 'input'),
@@ -596,7 +618,9 @@ def select_renderer(widget, data):
             'placeholder': widget.attrs.get('placeholder') or None,
             'autofocus': widget.attrs.get('autofocus') and 'autofocus' or None,
             'required': widget.attrs.get('required') and 'required' or None,            
-        }
+        }        
+        if disabled is True:
+            select_attrs['disabled'] = 'disabled'
         rendered = tag('select', *optiontags, **select_attrs)
         if widget.attrs['multivalued']:
             attrs = {
@@ -620,10 +644,13 @@ def select_renderer(widget, data):
                 'checked': (key in value) and 'checked' or None,
                 'name_': widget.dottedpath,
                 'id': cssid(widget, 'input', key),    
-                'class_': cssclasses(widget, data),    
+                'class_': cssclasses(widget, data),
             }
+            if (disabled and disabled is not True and key in disabled) \
+               or disabled is True:
+                attrs['disabled'] = 'disabled'                                 
             input = tag('input', **attrs)
-            text = tag('span', term)
+            text = tag('label', term, for_=attrs['id'])
             tags.append(tag('div', input, text,
                             **{'id': cssid(widget, tagtype, key)}))
         return select_exists_marker(widget, data) + u''.join(tags)
@@ -641,6 +668,11 @@ Vocabulary to be used for the selection list. Expects a dict-like or an iterable
 or a callable which returns one of both first. An iterable can consist out of 
 strings or out of tuples with ``(key, value)``.   
 """
+factory.doc['props']['select.disabled'] = """\
+Disables the whole widget or single selections. To disable the whole widget just
+set the value to 'True'. To disable single selection pass a iterable of keys to 
+disable, i.e. ``['foo', 'baz']``. Defaults to False.
+"""
 
 factory.register('select',
                  [select_extractor, generic_required_extractor], 
@@ -795,6 +827,7 @@ def email_extractor(widget, data):
 
 
 def email_renderer(widget, data):
+    # XXX: remove. Controlled form.novalidate instead
     if not widget.attrs['html5type']:
         widget.attrs['type'] = 'text'
     return input_generic_renderer(widget, data)
@@ -805,6 +838,7 @@ factory.doc['widget']['email'] = \
 """
 
 factory.defaults['email.type'] = 'email'
+# XXX: remove. Controlled form.novalidate instead
 factory.defaults['email.html5type'] = True
 factory.defaults['email.default'] = ''
 factory.defaults['email.required_class'] = 'required'
